pyqode.core.api package
=======================

.. toctree::
   :maxdepth: 4

Module content
--------------

.. automodule:: pyqode.core.api


Classes
-------

CodeEdit
++++++++

.. autoclass:: pyqode.core.api.CodeEdit
    :members:
    :undoc-members:
    :show-inheritance:

ColorScheme
+++++++++++

.. autoclass:: pyqode.core.api.ColorScheme
    :members:
    :undoc-members:
    :show-inheritance:

DelayJobRunner
++++++++++++++

.. autoclass:: pyqode.core.api.DelayJobRunner
    :members:
    :undoc-members:
    :show-inheritance:

FoldDetector
++++++++++++

.. autoclass:: pyqode.core.api.FoldDetector
    :members:
    :undoc-members:
    :show-inheritance:

FoldScope
+++++++++

.. autoclass:: pyqode.core.api.FoldScope
    :members:
    :undoc-members:
    :show-inheritance:

IndentFoldDetector
++++++++++++++++++
.. autoclass:: pyqode.core.api.IndentFoldDetector
    :members:
    :undoc-members:
    :show-inheritance:

Manager
+++++++
.. autoclass:: pyqode.core.api.Manager
    :members:
    :undoc-members:
    :show-inheritance:

Mode
++++

.. autoclass:: pyqode.core.api.Mode
    :members:
    :undoc-members:
    :show-inheritance:

Panel
+++++

.. autoclass:: pyqode.core.api.Panel
    :members:
    :undoc-members:
    :show-inheritance:

SyntaxHighlighter
+++++++++++++++++

.. autoclass:: pyqode.core.api.SyntaxHighlighter
    :members:
    :undoc-members:
    :show-inheritance:


TextBlockHelper
+++++++++++++++

.. autoclass:: pyqode.core.api.TextBlockHelper
    :members:
    :undoc-members:
    :show-inheritance:

TextBlockUserData
+++++++++++++++++
.. autoclass:: pyqode.core.api.TextBlockUserData
    :members:
    :undoc-members:
    :show-inheritance:

TextDecoration
++++++++++++++
.. autoclass:: pyqode.core.api.TextDecoration
    :members:
    :undoc-members:
    :show-inheritance:

TextHelper
++++++++++
.. autoclass:: pyqode.core.api.DelayJobRunner
    :members:
    :undoc-members:
    :show-inheritance:

